@@ -7,6 +7,7 @@ Construct a command (packet that is to be sent).
 """
 
 import asyncio
+
 # from collections import namedtuple
 from datetime import datetime as dt, timedelta as td
 from functools import total_ordering
@@ -249,42 +250,34 @@ class Command:
     def set_dhw_mode(cls, ctl_id, mode=None, active: bool = None, until=None, **kwargs):
         """Constructor to set/reset the mode of the DHW (c.f. parser_1f41)."""
 
-        if mode is not None:
-            if isinstance(mode, int):
-                mode = f"{mode:02X}"
-            elif not isinstance(mode, str):
-                raise TypeError(f"Invalid DHW mode: {mode}")
+        if mode is None and active is None:
+            raise ValueError("Invalid args: Both mode and active cant be None")
 
-            if mode in ZONE_MODE_LOOKUP:
-                mode = ZONE_MODE_LOOKUP[mode]
-            elif mode not in ZONE_MODE_MAP:
-                raise TypeError(f"Unknown DHW mode: {mode}")
+        if mode is None:  # and active is not None: TODO: use: advanced_override?
+            mode = "temporary_override" if until else "permanent_override"
+        elif isinstance(mode, int):
+            mode = f"{mode:02X}"
+        if mode in ZONE_MODE_MAP:
+            mode = ZONE_MODE_MAP[mode]
+        elif mode not in ZONE_MODE_LOOKUP:
+            raise TypeError(f"Invalid args: Unknown mode: {mode}")
 
-        if mode == ZONE_MODE_LOOKUP["follow_schedule"]:
-            if until is not None:  # active is ignored
-                raise ValueError("Invalid parameters: until should be None")
+        if active is None and mode != "follow_schedule":
+            raise ValueError(f"Invalid args: For {mode}, active cant be None")
+        elif active is not None and not isinstance(active, (bool, int)):
+            raise ValueError(f"Invalid args: active={active}, should be bool")
 
-        elif mode == ZONE_MODE_LOOKUP["permanent_override"] and until is not None:
-            raise ValueError("Invalid parameters: until should be None")
+        if until is None and mode == "temporary_override":
+            mode = "advanced_override"  # until = dt.now() + td(hour=1)
+        elif until is not None and mode in ("follow_schedule", "permanent_override"):
+            raise ValueError(f"Invalid args: For {mode}, until should be None")
 
-        elif mode == ZONE_MODE_LOOKUP["temporary_override"] and until is None:
-            until = dt.now() + td(hour=1)
+        assert mode in ZONE_MODE_LOOKUP, mode
 
-        elif not isinstance(active, bool):
-            raise ValueError(f"Invalid parameters: active={active}, should be bool")
-
-        elif until is None:
-            mode = ZONE_MODE_LOOKUP["permanent_override"]
-
-        else:
-            mode = ZONE_MODE_LOOKUP["temporary_override"]
-
-        active = "00" if active is None else f"{int(active):02X}"
-
-        payload = f"00{active}{mode}FFFFFF"
-
-        if until is not None:  # ZONE_MODE_LOOKUP[mode] == "04":
-            payload += dtm_to_hex(until)
+        payload = "00"
+        payload += "01" if bool(active) else "00"
+        payload += ZONE_MODE_LOOKUP[mode] + "FFFFFF"
+        payload += "" if until is None else dtm_to_hex(until)
 
         return cls("W", ctl_id, "1F41", payload, **kwargs)
 
@@ -364,22 +357,31 @@ class Command:
     def set_system_mode(cls, ctl_id, system_mode, until=None, **kwargs):
         """Constructor to set/reset the mode of a system (c.f. parser_2e04)."""
 
+        if system_mode is None:
+            raise ValueError("Invalid args: system_mode cant be None")
+
         if isinstance(system_mode, int):
             system_mode = f"{system_mode:02X}"
-        elif not isinstance(system_mode, str):
-            raise TypeError(f"Invalid system mode: {system_mode}")
-        elif system_mode in SYSTEM_MODE_LOOKUP:
-            system_mode = SYSTEM_MODE_LOOKUP[system_mode]
+        if system_mode in SYSTEM_MODE_MAP:
+            system_mode = SYSTEM_MODE_MAP[system_mode]
+        elif system_mode not in SYSTEM_MODE_LOOKUP:
+            raise TypeError(f"Invalid args: Unknown system_mode: {system_mode}")
 
-        if system_mode not in SYSTEM_MODE_MAP:
-            raise ValueError(f"Unknown system mode: {system_mode}")
+        # TODO: these need fixing
+        # if until is None and system_mode == "xxx":
+        #     system_mode = "advanced_override"  # until = dt.now() + td(hour=1)
+        # elif until is not None and system_mode in ("auto", "auto_with_reset"):
+        #     raise ValueError(f"Invalid args: For {system_mode}, until should be None")
 
-        until = dtm_to_hex(until) + ("00" if until is None else "01")
+        assert system_mode in SYSTEM_MODE_LOOKUP, system_mode
 
-        return cls("W", ctl_id, "2E04", f"{system_mode}{until}", **kwargs)
+        payload = SYSTEM_MODE_LOOKUP[system_mode]
+        payload += dtm_to_hex(until) + ("00" if until is None else "01")
+
+        return cls("W", ctl_id, "2E04", payload, **kwargs)
 
     @classmethod  # constructor for RQ/3220  # TODO
-    def get_opentherm_msg(cls, dev_id, msg_id, **kwargs):
+    def get_opentherm_data(cls, dev_id, msg_id, **kwargs):
         """Constructor to get (Read-Data) opentherm msg value (c.f. parser_3220)."""
         msg_id = msg_id if isinstance(msg_id, int) else int(msg_id, 16)
         payload = f"0080{msg_id:02X}0000" if parity(msg_id) else f"0000{msg_id:02X}0000"
@@ -481,40 +483,43 @@ class Command:
     ):
         """Constructor to set/reset the mode of a zone (c.f. parser_2349).
 
-        The setpoint has a resolution of 0.1 C. If a setpoint temperature is required,
-        but none is provided, evohome will use the maximum possible value.
+            The setpoint has a resolution of 0.1 C. If a setpoint temperature is required,
+            but none is provided, evohome will use the maximum possible value.
 
-        The until has a resolution of 1 min.
+            The until has a resolution of 1 min.
 
-        Incompatible combinations:
-        - mode == Follow & setpoint not None (will silently ignore setpoint)
-        - mode == Temporary & until is None (will silently ignore)
-        """
-        #  W --- 18:013393 01:145038 --:------ 2349 013 0004E201FFFFFF330B1A0607E4
-        #  W --- 22:017139 01:140959 --:------ 2349 007 0801F400FFFFFF
+            Incompatible combinations:
+            - mode == Follow & setpoint not None (will silently ignore setpoint)
+            - mode == Temporary & until is None (will silently ignore)
+            """
+            #  W --- 18:013393 01:145038 --:------ 2349 013 0004E201FFFFFF330B1A0607E4
+            #  W --- 22:017139 01:140959 --:------ 2349 007 0801F400FFFFFF
 
-        payload = f"{zone_idx:02X}" if isinstance(zone_idx, int) else zone_idx
+        if mode is None and setpoint is None:
+            raise ValueError("Invalid args: Both mode and setpoint cant be None")
 
-        if mode is not None:
-            if isinstance(mode, int):
-                mode = f"{mode:02X}"
-            elif not isinstance(mode, str):
-                raise TypeError(f"Invalid zone mode: {mode}")
+        if mode is None:  # and setpoint is not None: TODO: use: advanced_override?
+            mode = "temporary_override" if until else "permanent_override"
+        elif isinstance(mode, int):
+            mode = f"{mode:02X}"
+        if mode in ZONE_MODE_MAP:
+            mode = ZONE_MODE_MAP[mode]
+        elif mode not in ZONE_MODE_LOOKUP:
+            raise TypeError(f"Invalid args: Unknown mode: {mode}")
 
-            if mode in ZONE_MODE_LOOKUP:
-                mode = ZONE_MODE_LOOKUP[mode]
-            elif mode not in ZONE_MODE_MAP:
-                raise TypeError(f"Unknown zone mode: {mode}")
+        if setpoint is None and mode != "follow_schedule":
+            raise ValueError(f"Invalid args: For {mode}, setpoint cant be None")
+        elif setpoint is not None and not isinstance(setpoint, (int, float)):
+            raise ValueError(f"Invalid args: setpoint={setpoint}, should be float")
 
-        elif until is None:  # mode is None
-            mode = "advanced_override" if setpoint else "follow_schedule"
-        else:  # mode is None, until is not None:
-            mode = "temporary_override" if setpoint else "advanced_override"
-        if until is None:
-            mode = "advanced_override" if mode == "temporary_override" else mode
+        if until is None and mode == "temporary_override":
+            mode = "advanced_override"  # until = dt.now() + td(hour=1)
+        elif until is not None and mode in ("follow_schedule", "permanent_override"):
+            raise ValueError(f"Invalid args: For {mode}, until should be None")
 
         assert mode in ZONE_MODE_LOOKUP, mode
 
+        payload = f"{zone_idx:02X}" if isinstance(zone_idx, int) else zone_idx
         payload += temp_to_hex(setpoint)  # None means max, if a temp is required
         payload += ZONE_MODE_LOOKUP[mode] + "FFFFFF"
         payload += "" if until is None else dtm_to_hex(until)
@@ -556,7 +561,13 @@ class Command:
 
     @classmethod
     def _puzzle(
-        cls, msg_type="01", message=None, ordinal=0, interval=0, length=None, **kwargs
+        cls,
+        msg_type="01",
+        message=None,
+        ordinal=0,
+        interval=0,
+        length=None,
+        **kwargs,
     ):
 
         if msg_type == "00":
