@@ -5,21 +5,18 @@
 
 from collections import namedtuple
 import re
+from types import SimpleNamespace
 
 
 def slug(string: str) -> str:
     return re.sub(r"[\W_]+", "_", string.lower())
 
 
-_dev_mode_ = False
+DEV_MODE = _dev_mode_ = False
 
 # grep ' F[89ABxDE]' | grep -vE ' (0008|1F09/F8|1FC9|2D49/FD) '
 # grep ' F[89ABCDE]' | grep -vE ' (0008|1F09/xx|1FC9|0001|0009|1100|3150|3B00) '
 
-HGI_DEV_ID = "18:000730"  # default type and address of HGI, 18:013393
-NON_DEV_ID = "--:------"
-NUL_DEV_ID = "63:262142"  # 7FFFFF - send here if not bound?
-
 Address = namedtuple("DeviceAddress", "id, type")
 
 
@@ -27,15 +24,37 @@ def id_to_address(device_id) -> Address:
     return Address(id=device_id, type=device_id[:2])
 
 
-HGI_DEVICE = id_to_address(HGI_DEV_ID)
-NON_DEVICE = id_to_address(NON_DEV_ID)
-NUL_DEVICE = id_to_address(NUL_DEV_ID)
-
-DEFAULT_MAX_ZONES = 12
+DEFAULT_MAX_ZONES = 16 if DEV_MODE else 12
 # Evohome: 12 (0-11), older/initial version was 8
 # Hometronics: 16 (0-15), or more?
 # Sundial RF2: 2 (0-1), usually only one, but ST9520C can do two zones
 
+HGI_DEVICE_ID = "18:000730"  # default type and address of HGI, 18:013393
+NON_DEVICE_ID = "--:------"
+NUL_DEVICE_ID = "63:262142"  # 7FFFFF - send here if not bound?
+
+HGI_DEV_ADDR = id_to_address(HGI_DEVICE_ID)
+NON_DEV_ADDR = id_to_address(NON_DEVICE_ID)
+NUL_DEV_ADDR = id_to_address(NUL_DEVICE_ID)
+
+# ATTR_DEVICE_ID = "device_id"
+# ATTR_SENSOR_ID = "sensor_id"
+# ATTR_CTL_DEVICE_ID = "controller_id"
+# ATTR_DHW_SENSOR_ID = "sensor_id"
+# ATTR_HTG_DEVICE_ID = "heater_id"
+# ATTR_UFC_DEVICE_ID = "ufh_controller_id"
+# ATTR_RELAY_DEVICE_ID = "relay_id"
+
+ALL_DEVICE_ID = r"^[0-9]{2}:[0-9]{6}$"
+ZON_SENSOR_ID = r"^('01'|'03'|'04'|'12'|'22'|'34'):[0-9]{6}$"
+CTL_DEVICE_ID = r"^(01|23):[0-9]{6}$"
+DHW_SENSOR_ID = r"^07:[0-9]{6}$"
+GWY_DEVICE_ID = r"^18:[0-9]{6}$"
+HTG_DEVICE_ID = r"^(10|13):[0-9]{6}$"
+UFC_DEVICE_ID = r"^02:[0-9]{6}$"
+RLY_DEVICE_ID = r"^13:[0-9]{6}$"
+
+
 # Packet codes
 CODE_SCHEMA = {
     # main codes - every sync_cycle
@@ -296,6 +315,7 @@ DEVICE_TABLE = {
     "20": {"type": "VCE", "name": "HVAC?"},  # VCE-RF unit
     "32": {"type": "VMS", "name": "HVAC?"},  # sensor/switch
     "37": {"type": " 37", "name": "HVAC?"},  # VCE
+    "39": {"type": "VMS", "name": "HVAC?"},  # sensor/switch
     "49": {"type": " 49", "name": "HVAC?"},  # VCE switch
     # specials
     "63": {"type": "NUL", "name": "Null Device"},
@@ -337,11 +357,22 @@ DOMAIN_TYPE_MAP = {
     "FA": "hotwater_valve",  # DHW HW Valve (or UFH loop if src.type == "02"?)
     "FB": None,
     "FC": "heating_control",  # "heat_relay": BDR (Boiler, District heating), or OTB
-    "FD": None,  # seen with hometronics
+    "FD": "unknown",  # seen with hometronics
     "FF": "system",  # TODO: remove this, is not a domain
 }  # "21": "Ventilation",
 DOMAIN_TYPE_LOOKUP = {v: k for k, v in DOMAIN_TYPE_MAP.items() if k != "FF"}
 
+SystemMode = SimpleNamespace(
+    AUTO="00",
+    HEAT_OFF="01",
+    ECO="02",
+    AWAY="03",
+    DAY_OFF="04",
+    DAY_OFF_ECO="05",  # set to Eco when DayOff ends
+    AUTO_RESET="06",
+    CUSTOM="07",
+)
+
 SYSTEM_MODE_MAP = {
     "00": "auto",
     "01": "heat_off",
@@ -358,12 +389,12 @@ ZONE_MODE_MAP = {
     "00": "follow_schedule",
     "01": "advanced_override",  # until the next scheduled setpoint
     "02": "permanent_override",
-    # "03": "day_override",  # ignores until, uses duration of 20h 15m!
+    "03": "day_override",  # ignores until, uses duration of 20h 15m!
     "04": "temporary_override",  # requires an until (datetime)
 }
 ZONE_MODE_LOOKUP = {v: k for k, v in ZONE_MODE_MAP.items()}
 
-DHW_STATE_MAP = {"00": "Off", "01": "On"}
+DHW_STATE_MAP = {"00": "off", "01": "on"}
 DHW_STATE_LOOKUP = {v: k for k, v in DHW_STATE_MAP.items()}
 
 # Electric Heat - on/off relay (only)
@@ -388,18 +419,17 @@ DTM_LONG_REGEX = re.compile(
 DTM_TIME_REGEX = re.compile(r"[0-2]\d:[0-5]\d:[0-5]\d\.\d{3} ?")  # 13:15:00.123
 
 # Used by packet structure validators
-a = r"(-{3}|\d{3}|\.{3})"  # '...' was used by an older version of evofw3
-b = r"( I|RP|RQ| W)"
-c = r"(-{2}:-{6}|\d{2}:\d{6})"
-d = r"[0-9A-F]{4}"
-e = r"\d{3}"
-f = r"([0-9A-F]{2})+"
+r = r"(-{3}|\d{3}|\.{3})"  # RSSI, '...' was used by an older version of evofw3
+v = r"( I|RP|RQ| W)"  # Verb
+d = r"(-{2}:-{6}|\d{2}:\d{6})"  # Device ID
+c = r"[0-9A-F]{4}"  # Code
+l = r"\d{3}"  # Length # noqa: E741
+p = r"([0-9A-F]{2})+"  # Payload
 
-DEVICE_ID_REGEX = re.compile(f"^{c}$")
-COMMAND_REGEX = re.compile(f"^{b} {a} {c} {c} {c} {d} {e} {f}$")
-MESSAGE_REGEX = re.compile(f"^{a} {b} {a} {c} {c} {c} {d} {e} {f}$")
+DEVICE_ID_REGEX = re.compile(f"^{d}$")
+COMMAND_REGEX = re.compile(f"^{v} {r} {d} {d} {d} {c} {l} {p}$")
+MESSAGE_REGEX = re.compile(f"^{r} {v} {r} {d} {d} {d} {c} {l} {p}$")
 
-COMMAND_FORMAT = "{:<2} --- {} {} --:------ {} {:03d} {}"
 MSG_FORMAT_10 = "|| {:10s} | {:10s} | {:2s} | {:16s} | {:8s} || {}"
 MSG_FORMAT_18 = "|| {:18s} | {:18s} | {:2s} | {:16s} | {:8s} || {}"
 
@@ -411,13 +441,15 @@ ATTR_DHW_VALVE_HTG = "heating_valve"
 ATTR_HTG_CONTROL = "heating_control"  # aka boiler relay, heating appliance
 ATTR_HTG_PUMP = "heat_pump_control"  # same as ATTR_HTG_CONTROL, but parameters differ
 ATTR_HEAT_DEMAND = "heat_demand"
-ATTR_OPEN_WINDOW = "open_window"
+ATTR_WINDOW_OPEN = "window_open"
 ATTR_ORPHANS = "orphans"
 ATTR_SETPOINT = "setpoint"
 ATTR_STORED_HW = "stored_hotwater"
 ATTR_SYSTEM = "system"
 ATTR_TEMP = "temperature"
 ATTR_UFH_CONTROLLERS = "ufh_controllers"
+ATTR_ZONE_ACTUATORS = "zone_actuators"
+ATTR_ZONE_IDX = "zone_idx"
 ATTR_ZONE_SENSOR = "sensor"
 ATTR_ZONE_TYPE = "heating_type"
 ATTR_ZONES = "zones"
