@@ -742,7 +742,7 @@ class OtbGateway(Actuator, Device):
 
         if discover_flag & DISCOVER_SCHEMA:
             for msg_id in range(0x7C, 0x80):  # From OT v2.2: version numbers
-                self._gwy.send_cmd(Command.get_opentherm_msg(self.id, msg_id))
+                self._gwy.send_cmd(Command.get_opentherm_data(self.id, msg_id))
 
         if discover_flag & DISCOVER_PARAMS:
             pass
@@ -765,8 +765,11 @@ class OtbGateway(Actuator, Device):
             # 1B - Outside temperature
             # 1C - Return water temperature
             # 73 - OEM diagnostic code
+
             for msg_id in msg_ids:
-                self._gwy.send_cmd(Command.get_opentherm_msg(self.id, msg_id))
+                self._gwy.send_cmd(
+                    Command.get_opentherm_data(self.id, msg_id, retries=0)
+                )
 
     def _handle_msg(self, msg) -> bool:
         super()._handle_msg(msg)
@@ -1053,7 +1056,7 @@ class FanSwitch(BatteryState, Device):
         return self._msg_payload(self._msgs["22F1"], self.FAN_MODE)
 
     @property
-    def boost_timer(self) -> Optional[bool]:
+    def boost_timer(self) -> Optional[int]:
         return self._msg_payload(self._msgs["22F3"], self.BOOST_TIMER)
 
     @property
